#
# spec file for package krb5-auth-dialog
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2009 Dominique Leuenberger, Almere, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           krb5-auth-dialog
Version:        44.0.alpha1
Release:        1.6
Summary:        Kerberos 5 ticket monitoring tray applet
License:        GPL-2.0-or-later
Group:          Productivity/Security
URL:            https://www.gnome.org/
Source0:        https://download.gnome.org/sources/krb5-auth-dialog/44/%{name}-%{version}.tar.xz

BuildRequires:  krb5-devel
BuildRequires:  meson >= 0.53.0
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gio-2.0) >= 2.66
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.66
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.66
BuildRequires:  pkgconfig(gobject-2.0) >= 2.66
BuildRequires:  pkgconfig(gtk4) >= 4.4
BuildRequires:  pkgconfig(libadwaita-1) >= 1.2

%description
krb5-auth-dialog is a tray applet that monitors and refreshes your
Kerberos ticket. It pops up reminders when the ticket is about to
expire.

It features ticket autorenewal and supports pkinit.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%files
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}*
%{_libdir}/%{name}/
%{_datadir}/applications/*.desktop
%{_datadir}/dbus-1/services/org.gnome.KrbAuthDialog.service
%{_datadir}/glib-2.0/schemas/org.gnome.KrbAuthDialog.gschema.xml
%{_datadir}/icons/hicolor/*/status/krb*.*
%{_datadir}/metainfo/org.gnome.KrbAuthDialog.metainfo.xml
%{_mandir}/man?/*%{ext_man}
%{_sysconfdir}/xdg/autostart/*.desktop

%files lang -f %{name}.lang

%changelog
* Fri Feb 17 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 44.0.alpha1:
  + Port to GTK4 and libadwaita.
  + Rework prefs using mobile friendly widgets.
  + Fix PKINIT with Heimdal Kerberos.
  + Update examples to use Python3.
  + Cleanup and simplify (dropping ~1000 LOC).
- Adjust BuildRequires for gtk4 port:
  + Replace pkgconfig(gtk+-3.0) with pkgconfig(gtk4)
  + Add pkgconfig(libadwaita-1)
- Drop pkgconfig(libnm) buildRequires: no reference found in the
  build system.
* Thu Oct 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Switch to meson.
  + Adjust a bit better to smaller screen sizes.
  + Lots of bug fixes and modernization.
  + Drop tray icon (won't exist in GTK4).
  + Updated translations.
- Changes in BuildRequires following upstream changes:
  + Drop: intltool, update-desktop-files and pkgconfig(libnotify).
  + Add: meson, pkgconfig(gobject-2.0) and pkgconfig(gcr-3).
- Add meson macros following upstreams port and modernize spec.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Tue Jul 13 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Own %%{_datadir}/GConf and %%{_datadir}/GConf/gsettings: fix build.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Nov 12 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Update for newer GTK.
  + Bugfixes.
  + Updated translations.
- Update Url to https://www.gnome.org/: since the app doesn't have
  a specific home page is better to point to the GNOME site instead
  of its download page.
- Change libnm-glib to libnm pkgconfig(*) BuildRequires: following
  upstream change.
- Add gio-2.0, gio-unix-2.0 and gmodule-2.0 pkgconfig(*)
  BuildRequires: they were already being used and pulled along with
  the ever declared pkgconfig(glib-2.0) since they live in the same
  devel package.
- Add conditional use to translation-update-upstream: SLE-only
  requirement.
- Drop bison and flex BuildRequires and --disable-scrollkeeper
  configure parameter: the last is no longer available and the
  former ones are not used/needed anymore.
- Drop %%glib2_gsettings_schema_*, %%desktop_database_*,
  %%icon_theme_cache_* post/postun scriptlets and
  %%glib2_gsettings_schema_requires macro: no longer needed since
  RPM file triggers.
- Drop %%clean section as its use is obsolete and replace pristine
  job macro with %%{?_smp_mflags} macro as handler of number of jobs
  available for make.
* Sat Jul 23 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Use yelp-tools instead of gtk-doc-utils.
  + Remove some deprecated macros.
  + Updated translations.
- Replace gnome-doc-utils-devel for yelp-tools BuildRequires
  following upstream changes.
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 3.15.4:
  + Use GtkGrid instead of deprecated GtkVBox.
  + Minor debug cleanups.
  + Slightly improve ticket list view.
  + Updated translations.
- Changes from version 3.15.1:
  + Make dialog layouts consistent regarding header bars.
  + Fix wrong ticket properties in prefs.
  + Remove notifiations in SIGTERM and SIGQUIT.
  + Fix pkinit configuration.
  + Use GResource.
  + Updated translations.
* Sat Oct 25 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Fix empty principal name (deb#762906).
  + Remote GTK deprecations.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Move dialog buttons into header bar.
  + Adjust to new GApplication flags (lp#1311487).
  + Properly reprompt for a password on KRB5_GET_IN_TKT_LOOP.
  + Updated translations.
* Thu Mar 28 2013 zaitor@opensuse.org
- Update to version 3.8.0:
  + Use an app menu instead of a menu bar.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Use GSettings instead of GConf.
  + Hide configuration tickets by default (bgo#649830).
  + Updated translations.
- Drop pkgconfig(gconf-2.0) BuildRequires: no longer needed after
  the port to GSettings.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Fix DBus activation
  + Add missing categories to the desktop file
  + Fix options in documentation
  + Updated translations.
- Drop krb5-auth-dialog-fix-desktop.patch: fixed upstream.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Use GtkApplication
  + Turn ticket dialog into the main window that gets shown when
    krb5-auth-dialog is invoked multiple times. This makes the
    prefs easily accessible.
  + Fix crash when displaying empty ticket dialog
  + Updated translations.
- Add krb5-auth-dialog-fix-desktop.patch: add categories to
  .desktop file, taken from git.
- Drop krb5-auth-dialog-no-g-c-c.patch: fixed upstream.
- Drop call to autoreconf: it was only needed for patch above.
- Drop --with-gtk=3.0 option from configure: this option is now
  gone.
- Use GNOME, GTK, System, Network categories in the
  krb5-auth-dialog.desktop, since the upstream ones don't pass our
  checks.
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Move preferences from cc into the app (bgo#657292)
  + Update ticket list on ccache changes
  + Add menu bar to ticket dialog making help accessible again
  + Updated translations.
- Remove now unneeded pkgconfig(libgnome-control-center)
  BuildRequires.
- Add krb5-auth-dialog-no-g-c-c.patch: fix configure flag to really
  not needed pkgconfig(libgnome-control-center).
- Add autoreconf call, needed for above patch.
* Thu Apr 28 2011 vuntz@opensuse.org
- Move to pkgconfig()-style BuildRequires:
  + Old ones: NetworkManager-devel, gconf2-devel, gtk3-devel,
    libnotify-devel.
  + New ones: gconf-2.0, glib-2.0, gtk+-3.0, libnm-glib, libnotify.
- Drop dbus-1-glib-devel BuildRequires: the code got ported to
  GDBus.
- Call %%suse_update_desktop_file for gnome-ka-panel.desktop.
* Thu Apr 28 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Fix documentation of --auto
  + Updated translations.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Fix DBus activation
  + Fix missing initial notification
  + Updated translations.
- Changes from version 2.91.93:
  + cc-panel: Move pkinit properties to separate tab
  + Update for NetworkManager 0.9
  + Minor bug fixes
- Changes from version 2.91.91:
  + Migrate to GDBus (bgo#622885)
- Changes from version 2.91.90:
  + Check credential cache right after startup so the user gets
    immediate feedback about her/his Kerberos tickets.
  + Make "always run" the default, don't exit when no ticket cache
    exists.
  + Try harder to detect the notification daemon's persistence
    capabilities during the autostart phase (bgo#642666).
- Changes from version 2.91.6:
  + Add "Get ticket" button to notifications
  + Disable tray icon if the notification server supports
    persistent notifications.
  + Move preferences to a gnome-control-center panel
  + Display account expiry prompts returned by the KDC
  + Drop gtksecentry and use GtkEntryBuffer with secmem instead
  + Use NMClient GObject instead of deprecated functions
  + Install desktop file to /u/s/applications so GNOME shell can
    find the icons.
- Change gtk2-devel BuildRequires to gtk3-devel, and pass
  - -with-gtk=3.0 to configure (instead of --with-gtk=2.0).
- Add pkgconfig(libgnome-control-center) BuildRequires.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Sun Sep 12 2010 vuntz@opensuse.org
- Update to version 0.17:
  + Add AFS plugin
  + Add --with-gtk to select the GTK+ 2 or 3
  + Updated translations.
- Drop krb5-auth-dialog-nonvoid.patch: fixed upstream.
- Pass --with-gtk=2.0 to configure to make sure we build against
  the version we want.
* Thu Aug  5 2010 vuntz@opensuse.org
- Change group from System/Security to Productivity/Security to
  make rpmlint happy.
- Add pam-devel BuildRequires to build PAM plugin.
* Mon Aug  2 2010 dimstar@opensuse.org
- Update to version 0.16:
  + Add plugin system
  + Memory leaks plugged
  + Bug fixes
  + Make -DSEAL safe
  + Updated translations.
- Pass --disable-static to configure.
- Add krb5-auth-dialog-nonvoid.patch, from upstream git, to fix
  brp checks.
* Tue Apr  6 2010 vuntz@opensuse.org
- Update to version 0.15:
  + Add DBus signals for ticket acquisition, expiry and renewal.
  + Bug fixes.
  + Updated translations.
* Fri Nov 13 2009 vuntz@opensuse.org
- Update to version 0.14:
  + add ticket flags to "list tickets" dialog
  + add manpage for krb5-auth-dialog-preferences
  + bug fixes
  + updated translations
* Thu Oct  1 2009 vuntz@opensuse.org
- Update to version 0.13:
  + add "list tickets" dialog
  + plug memory leaks
  + lots of bug fixes
  + updated translations
* Fri Jul 31 2009 vuntz@novell.com
- Update to version 0.12:
  + ease PKINIT smartcard setup
  + add new icons
  + minor bug fixes
  + updated translations
* Tue Jun 16 2009 vuntz@novell.com
- Update to version 0.11:
  + add a user manual
  + add svg and 48x48 icons, use them in notifications
  + add DBus API to destroy ticket cache (can be used by e.g. on
    laptop suspend, screensaver, ...)
  + cleanups and bug fixes
  + updated translations
- Add gnome-doc-utils-devel BuildRequires.
- Pass --disable-scrollkeeper to configure.
- Package new icons.
* Wed May 27 2009 vuntz@novell.com
- Update to version 0.10:
  + allow to turn off notifications easily
  + use GtkBuilder instead of Libglade
  + reduce number of translatable strings
  + various i18n fixes
  + updated translations
- Remove libglade2-devel BuildRequires.
* Mon May 18 2009 vuntz@novell.com
- Do not use tabs, remove trailing white spaces.
- Add BuildRequires: NetworkManager-devel, bison, flex,
  libnotify-devel
- Do not add categories that are already present to desktop files.
- Split lang package.
* Wed May 13 2009 dominique-obs@leuenberger.net
- Initial package, created during Community Week 1
